Imports System.Drawing
Imports System.ComponentModel

''' <summary>
''' Dieses Controls Beschriftung läßt sich durch Veränderung seiner
''' CaptionStringFormat-Property manipulieren
''' </summary>
Public Class StringFormatTester : Inherits Control

    Private ReadOnly _CaptionStringFormat As StringFormat = New StringFormat
    Private _Brush As New SolidBrush(Color.Black)

    Protected Overloads Overrides Sub Dispose(ByVal disposing As Boolean)
        If Not MyBase.IsDisposed Then
            For Each D As IDisposable In New IDisposable() {_Brush, _CaptionStringFormat}
                D.Dispose()
            Next
        End If
        MyBase.Dispose(disposing)
    End Sub

    'Einstellung: Im Designer den Knoten der Property "CaptionStringFormat" erweitern, und Einstellungen vornehmen
    'Es kann das vertikale und horizontale Alignment bestimmt werden, ob der Text umgebrochen wird (FormatFlags), welche Zeichen gekürzt werden, wenn der Text zu lang ist (Trimming)
    'Die Änderungen sind sofort sichtbar - kein Kompilieren erforderlich
    <TypeConverter(GetType(ExpandableObjectConverter))> _
     <Browsable(True)> _
     <Category("Darstellung")> _
     <Description("Einige interessante Einstellmöglichkeiten der Schrift-Darstellung")> _
     <DesignerSerializationVisibility(DesignerSerializationVisibility.Content)> _
    Public ReadOnly Property CaptionStringFormat() As StringFormat
        Get
            If Me.DesignMode Then Invalidate()
            Return _CaptionStringFormat
        End Get
    End Property

    Protected Overrides Sub OnTextChanged(ByVal e As System.EventArgs)
        MyBase.OnTextChanged(e)
        Invalidate()
    End Sub

    Protected Overrides Sub OnSizeChanged(ByVal e As System.EventArgs)
        MyBase.OnSizeChanged(e)
        MyBase.Invalidate() 'Neuzeichnung meiner Caption gewährleisten
    End Sub

    Protected Overrides Sub OnPaint(ByVal e As PaintEventArgs)
        MyBase.OnPaint(e)
        If MyBase.ForeColor <> _Brush.Color Then
            _Brush.Dispose()
            _Brush = New SolidBrush(MyBase.ForeColor)
        End If
        With Me.ClientRectangle
            Dim Rct As New Rectangle(.Location, .Size - New Size(1, 1))
            e.Graphics.DrawRectangle(Pens.Black, Rct)
            e.Graphics.DrawString(MyBase.Text, MyBase.Font, _Brush, Rct, _CaptionStringFormat)
        End With
    End Sub

End Class